# Tools <!-- omit in toc -->

The following tools are available for this project:

- [createTestReport](#createtestreport)
- [lobster](#lobster)
- [plantuml](#plantuml)
- [req2docx](#req2docx)
- [req2markdown](#req2markdown)
- [req2rst](#req2rst)
- [sphinx](#sphinx)
- [tc2markdown](#tc2markdown)
- [tc2rst](#tc2rst)

Converter support for the pyTRLCConverter project model files is described in the
[ProjectConverter Readme](./ProjectConverter/README.md) file.

## createTestReport

Used to execute the tests and creating a test report including the coverage and test results.

[Details](./createTestReport/README.md)

## lobster

Used to create the traceability report on code and requirements base.

[Details](./lobster/README.md)

## plantuml

Used to download on demand the PlantUML java jar file, which is required by other tooling.

[Details](./plantuml/README.md)

## req2docx

Used to convert the requirements written with TRLC to the docx format.

[Details](./req2docx/README.md)

## req2markdown

Used to convert the requirements written with TRLC to the Markdown format.

[Details](./req2markdown/README.md)

## req2rst

Used to convert the requirements written with TRLC to the reStructuredText format.

[Details](./req2rst/README.md)

## sphinx

Used to generate static HTML files, which will be deployed on Github pages.

[Details](./sphinx/README.md)

## tc2markdown

Used to convert the test cases written with TRLC to the Markdown format.

[Details](./tc2markdown/README.md)

## tc2rst

Used to convert the test cases written with TRLC to the reStructuredText format.

[Details](./tc2rst/README.md)
